==> quassel_0.6.3.orig.tar.bz2: quassel-0.6.3/src/core/coresettings.cpp <==
/***************************************************************************
 *   Copyright (C) 2005-09 by the Quassel Project                          *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "coresettings.h"

#include "quassel.h"

CoreSettings::CoreSettings(const QString group) : Settings(group, Quassel::buildInfo().coreApplicationName) {

}

CoreSettings::~CoreSettings() {
}

void CoreSettings::setStorageSettings(const QVariant &data) {
  setLocalValue("StorageSettings", data);
}

QVariant CoreSettings::storageSettings(const QVariant &def) {
  return localValue("StorageSettings", def);
}

// FIXME remove
QVariant CoreSettings::oldDbSettings() {
  return localValue("DatabaseSettings");
}

void CoreSettings::setCoreState(const QVariant &data) {
  setLocalValue("CoreState", data);
}

QVariant CoreSettings::coreState(const QVariant &def) {
  return localValue("CoreState", def);
}

==> quassel-0.9.1.tar.bz2: quassel-0.9.1/src/core/coresettings.cpp <==
/***************************************************************************
 *   Copyright (C) 2005-2013 by the Quassel Project                        *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "coresettings.h"

#include "quassel.h"

CoreSettings::CoreSettings(const QString group) : Settings(group, Quassel::buildInfo().coreApplicationName)
{
}


CoreSettings::~CoreSettings()
{
}


void CoreSettings::setStorageSettings(const QVariant &data)
{
    setLocalValue("StorageSettings", data);
}


QVariant CoreSettings::storageSettings(const QVariant &def)
{
    return localValue("StorageSettings", def);
}


// FIXME remove
QVariant CoreSettings::oldDbSettings()
{
    return localValue("DatabaseSettings");
}


void CoreSettings::setCoreState(const QVariant &data)
{
    setLocalValue("CoreState", data);
}


QVariant CoreSettings::coreState(const QVariant &def)
{
    return localValue("CoreState", def);
}
